==> speech-analytic-testing_2.1.1_database.tar.gz: database/mssql/procedures/GetEvaluationReview.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[Id]													'id',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	SELECT ERC.[LargeInteractionId]									'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.2.0_database.tar.gz: database/mssql/procedures/GetEvaluationReview.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationReview] (
	@VCC Varchar(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(50) = NULL,
	@SupervisorId VARCHAR(50) = NULL,
	@AgentId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW
	SELECT ER.[VCC]													'vcc',
			ER.[Id]													'id',
			ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[InteractionId]										'interactionId',
			ER.[SupervisorId]										'supervisorId',
			ER.[Review]												'review'
		FROM [dbo].[EvaluationReview] ER (NOLOCK) 
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])

	-- SELECCIONAMOS LOS CAMPOS DE LA TABLA EVALUATION-REVIEW-COMMITMENT
	EXEC [dbo].[GetEvaluationReviewCommitments] @VCC, @EvaluationPlanId, @InteractionId, @SupervisorId, @AgentId
	/*
	SELECT ER.[EvaluationPlanId]									'evaluationPlanId',
			ER.[SupervisorId]										'supervisorId',
			ERC.[LargeInteractionId]								'largeInteractionId',
			ERC.[AgentId]											'agentId',
			ERC.[Commitment]										'commitment',
			ERC.[CreatedDate]										'eventDate',
			ERC.[CreatedDate]										'createdDate'
		FROM [dbo].[EvaluationReviewCommitment] ERC (NOLOCK) 
		INNER JOIN [dbo].[EvaluationReview] ER (NOLOCK)
			ON ER.[VCC] = ERC.[VCC]
				AND ER.[Id] = ERC.[EvaluationReviewId]
		WHERE ER.[VCC] = @VCC
			AND ER.[EvaluationPlanId] = @EvaluationPlanId
			AND ER.[InteractionId] = @InteractionId
			AND ER.[SupervisorId] = ISNULL(@SupervisorId, ER.[SupervisorId])
			AND ERC.[AgentId] = ISNULL(@AgentId, ERC.[AgentId])
		ORDER BY [ERC].[CreatedDate] DESC
	*/
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
